/*
    Copyright (  C ) 2003 Arnold Krille <arnold@arnoldarts.de>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation;
    version 2 of the License.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.

*/

#include "klevelmeter_linebars.h"

#include <kdebug.h>
#include <qpainter.h>

KLevelMeter_LineBars::KLevelMeter_LineBars( Arts::KLevelMeter_impl* impl, QWidget* parent, long substyle, long count, float _dbmin, float _dbmax ) : KLevelMeter_Template( impl, parent, substyle, count, _dbmin, _dbmax ) {
//kdDebug()<<"KLevelMeter_LineBars::KLevelMeter_LineBars( Arts::KLevelMeter_impl* "<<impl<<", QWidget* "<<parent<<", long "<<substyle<<", long "<<count<<", float "<<_dbmin<<", float "<<_dbmax<<" )"<<endl;
	this->setMinimumSize( 5, 5 );
	this->substyle( substyle );
	_stdcolors = colorGroup();
}

void KLevelMeter_LineBars::invalue( float n, float p ) {
	_value = amptondb( n );
	_peak  = amptondb( p );
	repaint();
}

void KLevelMeter_LineBars::substyle( long n ) {
	//kdDebug() << k_funcinfo << n << endl;
	_substyle = n;
}
long KLevelMeter_LineBars::substyle() { return _substyle; }

/*
	QPixmap as buffer does remove the flicker some what but it makes the widget _slow_
	so we have to live with some flicker if you have 10 LevelMeters in fullscreen.
*/
void KLevelMeter_LineBars::paintEvent( QPaintEvent* ) {
	QPainter p( this );
//	if ( _peak=>1 ) p.setBrush( QColor( 255,0,0 ) );
//	else {
		if ( _substyle & 1 ) p.setBrush( ( _peak<1 )?QColor( 0,0,255 ):QColor( 255,0,0 ) );
			else p.setBrush( ( _peak<1 )?color( _value ):QColor( 255,0,0 ) );
//	}
	if ( _substyle & 2 ) this->setPaletteBackgroundColor( p.brush().color().dark() );
		else this->setPaletteBackgroundColor( _stdcolors.background() );
	p.setPen( NoPen );
	p.translate( 0, rect().bottom() );
	// Value
	int h = int( this->height()*_value );
	p.drawRect( 0, 0, this->width(), -h );
	// PeakBar
	if ( _peak > 1.0/1000 ) {
		//p.setPen( QColor( 0,0,255 ) );
		QColor bgcolor = this->paletteBackgroundColor();
		p.setPen( QColor( 255-bgcolor.red(), 255-bgcolor.green(), 255-bgcolor.blue() ) );
		h = int( this->height()*_peak );
		p.drawLine( 0, -h, this->width(), -h );
	}
}

/**
	Planned feature: a little Tooltip showing the actual value of the volume in deziBel and perhaps as linear scaleFactor
*/
void KLevelMeter_LineBars::mouseMoveEvent( QMouseEvent* /*qme*/ ) {
//kdDebug()<<"KLevelMeter_LineBars::mouseMoveEvent(QMouseEvent* "<<qme<<" )"<<endl;
//kdDebug()<<"qme.y()="<<this->height()-qme->y()<<" db="<<db<<" dbtoamp(db)="<<dbtoamp( db )<<endl;
}

#include <klevelmeter_linebars.moc>
// vim: sw=4 ts=4
