/***************************************************************************
                          artscontrolapplet.cpp  -  description
                             -------------------
    begin                : Don Jan 30 20:42:53 CET 2003
    copyright            : (C) 2003 by Arnold Krille
    email                : arnold@arnoldarts.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <kglobal.h>
#include <klocale.h>
#include <kconfig.h>
#include <kapp.h>
#include <kmessagebox.h>
#include <kdebug.h>
#include <qcursor.h>

#include "artscontrolapplet.h"
#include "artscontrolapplet_private.h"

extern "C"
{
  KPanelApplet* init( QWidget *parent, const QString configFile)
  {
    KGlobal::locale()->insertCatalogue("artscontrol");
    return new ArtsControlApplet(configFile, KPanelApplet::Normal,
                      KPanelApplet::About /*| KPanelApplet::Help | KPanelApplet::Preferences*/,
                      parent, "artscontrolapplet");
  }
}

ArtsControlApplet::ArtsControlApplet(const QString& configFile, Type type, int actions, QWidget *parent, const char *name) : KPanelApplet(configFile, type, actions, parent, name)
{
kdDebug()<<"ArtsControlApplet::ArtsControlApplet( const QString& "<<configFile<<", Type "<<type<<", int "<<actions<<", QWidget* "<<parent<<", const char* "<<name<<" )"<<endl;
	//this->setMaximumSize( 100, 100 );
	// Get the current application configuration handle
	ksConfig = config();

	p = new ArtsControlAppletPrivate( this );
	if( !p->barts ) KMessageBox::information(0, i18n("Something with the ArtsServer went wrong."));  

	p->layout = new QBoxLayout( this, QBoxLayout::LeftToRight );
	p->layout->setSpacing( 2 );

	if( p->barts ) {
		p->volumeslider = new VolumeSlider( p->volume, this, "Master" );
		p->layout->addWidget( p->volumeslider, Qt::AlignCenter );

		p->vu = Arts::StereoVolumeControlGui( p->volume );
		p->vuw = new KArtsWidget( p->vu, this );
		p->vuw->setMinimumSize( 16,16 );
		p->layout->addWidget( p->vuw );
	}

	resetLayout();

kdDebug()<<"ArtsControlApplet::ArtsControlApplet() finished."<<endl;
}

ArtsControlApplet::~ArtsControlApplet() {
kdDebug()<<k_funcinfo<<endl;
}

#include <kaboutdata.h>
#include <kaboutapplication.h>

void ArtsControlApplet::about() {
	KAboutData about( "simpleartscontrolapplet", I18N_NOOP( "Simple Arts Control Applet" ), "0.1 / kdenonbeta",
		"A simple kickerapplet to control aRts.",
		KAboutData::License_GPL, "(c) 2003 by Arnold Krille" );
	about.addAuthor( "Arnold Krille", I18N_NOOP( "Author of the Applet" ), "arnold@arnoldarts.de" );
	about.addCredit( "Stefan Westerfeld", I18N_NOOP( "Thanks for creating aRts!!!" ) );
	KAboutApplication a( &about, this );
	a.exec();
}

void ArtsControlApplet::help() {
	KMessageBox::information(0, i18n("This is a help box"));
}

void ArtsControlApplet::preferences() {
	KMessageBox::information(0, i18n("This is a preferences box"));  
}

int ArtsControlApplet::widthForHeight( int /*h*/ ) const {
//kdDebug()<<"ArtsControlApplet::widthForHeight( int "<<h<<" )"<<endl;
	return p->layout->sizeHint().width();
}

int ArtsControlApplet::heightForWidth( int /*w*/ ) const {
//kdDebug()<<"ArtsControlApplet::heightForWidth( int "<<w<<" )"<<endl;
	return p->layout->sizeHint().height();
}

void ArtsControlApplet::resizeEvent( QResizeEvent * /*_Event*/ ) {
//kdDebug()<<"ArtsControlApplet::resizeEvent( QResizeEvent * )"<<endl;
}

void ArtsControlApplet::mousePressEvent( QMouseEvent* ev ) {
//kdDebug()<<"ArtsControlApplet::mousePressEvent( QMouseEvent* "<<ev<<" )"<<endl;
	if ( Qt::RightButton == ev->button() /*|| Qt::LeftButton == ev->button()*/ )
		p->menu->exec( QCursor::pos() );
}

void ArtsControlApplet::positionChange( Position ) {
	resetLayout();
}

void ArtsControlApplet::resetLayout() {
kdDebug()<<k_funcinfo<<" position()="<<position()<<endl;
/*	switch ( position() )
	{
		case Horizontal:
			p->volumeslider->setOrientation( Qt::Vertical );
//			p->volumeslider->setOrientation( Qt::Horizontal );
			break;
		case Vertical:
//			p->volumeslider->setOrientation( Qt::Horizontal );
			p->volumeslider->setOrientation( Qt::Vertical );
			break;
		default: break;
	}*/
}

void ArtsControlAppletPrivate::AM() {
kdDebug()<<k_funcinfo<<endl;
	if ( !am ) {
		am = new Gui_AUDIO_MANAGER();
		connect( am, SIGNAL( closed() ), this, SLOT( AM() ) );
	} else {
		delete am;
		am = 0;
	}
}

void ArtsControlAppletPrivate::SV() {
kdDebug()<<k_funcinfo<<endl;
	if ( !sv ) {
		sv = new FFTScopeView( arts->server() );
		connect( sv, SIGNAL( closed() ), this, SLOT( SV() ) );
	} else {
		delete sv;
		sv = 0;
	}
}

void ArtsControlAppletPrivate::SVinline() {
kdDebug()<<k_funcinfo<<endl;
	if ( !svinline ) {
		svinline = new FFTScopeView( arts->server(), _parent );
		svinline->setMargin( 1 ); svinline->setLineWidth( 1 ); svinline->setFrameStyle( QFrame::Panel|QFrame::Sunken );
		connect( svinline, SIGNAL( closed() ), this, SLOT( SVinline() ) );
		layout->addWidget( svinline );
	} else {
		delete svinline;
		svinline = 0;
	}
	_parent->updatelayout();
}

void ArtsControlAppletPrivate::ASV() {
kdDebug()<<k_funcinfo<<endl;
	if ( !asv ) {
		asv = new ArtsStatusView( arts->server() );
		connect( asv, SIGNAL( closed() ), this, SLOT( ASV() ) );
	} else {
		delete asv;
		asv = 0;
	}
}

void ArtsControlAppletPrivate::MMV() {
kdDebug()<<k_funcinfo<<endl;
	if ( !mmv ) {
		mmv = new MidiManagerView();
		connect( mmv, SIGNAL( closed() ), this, SLOT( MMV() ) );
	} else {
		delete mmv;
		mmv = 0;
	}
}

void ArtsControlAppletPrivate::EV() {
kdDebug()<<k_funcinfo<<endl;
	if ( !ev ) {
		ev = new EnvironmentView( defaultEnvironment() );
		connect( ev, SIGNAL( closed() ), this, SLOT( EV() ) );
	} else {
		delete ev;
		ev = 0;
	}
}

void ArtsControlAppletPrivate::MTV() {
kdDebug()<<k_funcinfo<<endl;
	if ( !mtv ) {
		mtv = new MediaTypesView();
		connect( mtv, SIGNAL( closed() ), this, SLOT( MTV() ) );
	} else {
		delete mtv;
		mtv = 0;
	}
}

void ArtsControlAppletPrivate::moreBars() { vu.left().count( vu.left().count()+10 ); vu.right().count( vu.right().count()+10 ); }
void ArtsControlAppletPrivate::lessBars() { vu.left().count( vu.left().count()-10 ); vu.right().count( vu.right().count()-10 ); }

void ArtsControlAppletPrivate::styleNormalBars() { vu.left().style( Arts::lmNormalBars ); vu.right().style( Arts::lmNormalBars ); _parent->updatelayout(); }
void ArtsControlAppletPrivate::styleFireBars()   { vu.left().style( Arts::lmFireBars   ); vu.right().style( Arts::lmFireBars   ); _parent->updatelayout(); }
void ArtsControlAppletPrivate::styleLineBars()   { vu.left().style( Arts::lmLineBars   ); vu.right().style( Arts::lmLineBars   ); _parent->updatelayout(); }
void ArtsControlAppletPrivate::styleLEDs()       { vu.left().style( Arts::lmLEDs       ); vu.right().style( Arts::lmLEDs       ); _parent->updatelayout(); }
void ArtsControlAppletPrivate::styleAnalog()     { vu.left().style( Arts::lmAnalog     ); vu.right().style( Arts::lmAnalog     ); _parent->updatelayout(); }
void ArtsControlAppletPrivate::styleSmall()      { vu.left().style( Arts::lmSmall      ); vu.right().style( Arts::lmSmall      ); _parent->updatelayout(); }

// vim: sw=4 ts=4
#include "artscontrolapplet.moc"
#include "artscontrolapplet_private.moc"
