/*

    Copyright (C) 2000-2001 Stefan Westerfeld
	                        <stefan@space.twc.de>
                  2003 Arnold Krille <arnold@arnoldarts.de

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

    */

#ifndef MAIN_H
#define MAIN_H
#include <qiomanager.h>
#include <dispatcher.h>
#include <qmessagebox.h>
#include <kapplication.h>
#include <qframe.h>
#include <kmainwindow.h>
#include <kcmdlineargs.h>
#include <kaboutdata.h>
#include <klocale.h>
#include <kstdaction.h>
#include <qlayout.h>
#include <qpushbutton.h>
#include <artsflow.h>
#include <soundserver.h>
#include <qobject.h>
#include <kartswidget.h>
#include <flowsystem.h>
#include <artsmodules.h>

class LevelMeter;
class PeakBar;
class PeakLevelMeter;
class VScale;

class FreeVerbView : public QWidget {
	Q_OBJECT
protected:
	Arts::Synth_FREEVERB freeverb;
	Arts::SimpleSoundServer server;
	long effectID;

	void closeEvent(QCloseEvent *e);
public:
	FreeVerbView(Arts::SimpleSoundServer server);
	~FreeVerbView();
signals:
	void closed();
};

class FFTScopeView;
class MediaTypesView;
class Gui_AUDIO_MANAGER;
class ArtsStatusView;
class MidiManagerView;
class EnvironmentView;
class QSlider;
class KArtsWidget;

class VControl : public QFrame {
	Q_OBJECT
protected:
	class StereoLevelMeter *stereoMeter;
	FFTScopeView *scopeView;
	MediaTypesView *mediaView;
	FreeVerbView *freeVerbView;
	Gui_AUDIO_MANAGER *audioManager;
	ArtsStatusView *artsStatusView;
	MidiManagerView *midiManagerView;
	EnvironmentView *environmentView;
	QSlider *slider;
	Arts::StereoVolumeControl svc;
//#if 0
	Arts::StereoVolumeControlGui svcgui;
	KArtsWidget *svcguiw;
//#endif
	Arts::SoundServerV2 server;
	bool inUpdate;
	
	QBoxLayout *boxLayout;

public:
	VControl(QWidget *parent);
	~VControl();

public slots:
	void updateVolume(float newVolume);
	void updateScales();
	void setVolume(int vol);
	void useOldVolumeBar(int old);
	void showScopeView();
	void showMediaView();
	void showAudioManager();
	void showMidiManager();
	void showEnvironment();
	void showFreeVerbView();
	void showArtsStatusView();
};

class MainWindow : public KMainWindow {
	Q_OBJECT
protected:
	VControl *vc;
	KToggleAction *showOldVolumeDisplay;

public slots:
	void toggleVolumeBar();

public:
	MainWindow();
};

//Arts::Environment::Container defaultEnvironment();

#endif /* MAIN_H */
